@@ -111,7 +111,7 @@ class TimeseriesGenerator(object):
     def __len__(self):
         if self.batch_size == sys.maxsize:
             return 1
-        return int((self.end_index - self.start_index - self.length + 1 - self.length_output + self.overlap - self.augmentation)//(self.batch_size * self.stride)) + 1
+        return int((self.end_index - self.start_index - self.length + 1 - self.length_output + self.overlap + self.augmentation)//(self.batch_size * self.stride)) + 1
 
     def __getitem__(self, index):
         i = self.start_index + self.length
